
from flowhigh.model.Expr import Expr
from flowhigh.model.Direction import Direction
from flowhigh.model.BaseExpr import BaseExpr


class Rotate(BaseExpr):
    nameColumn: str = None
    valueColumn: str = None
    pivotColumn: Expr = None
    columnList: list = []
    type_: str = None
    columnAlias: list = []
    aggregate: str = None

    def __init__(self):
        super().__init__()



from flowhigh.model.TreeNode import TreeNode

class RotateBuilder (object):
    construction: Rotate

    
    def __init__(self) -> None:
        super().__init__()
        self.construction = Rotate()
    
    def with_nameColumn(self, nameColumn: str):
        child = nameColumn
        self.construction.nameColumn = child
    
    def with_pos(self, pos: str):
        child = pos
        self.construction.pos = child
    
    def with_valueColumn(self, valueColumn: str):
        child = valueColumn
        self.construction.valueColumn = child
    
    def with_columnList(self, columnList: list):
        child = columnList
        for node in list(filter(lambda el: TreeNode in el.__class__.mro(), columnList)):
            self.construction.add_child(node)
        self.construction.columnList = child
    
    def with_pivotColumn(self, pivotColumn: Expr):
        child = pivotColumn
        if TreeNode in Expr.mro():
            self.construction.add_child(child)
        self.construction.pivotColumn = child
    
    def with_alias(self, alias: str):
        child = alias
        self.construction.alias = child
    
    def with_type(self, type_: str):
        child = type_
        self.construction.type_ = child
    
    def with_columnAlias(self, columnAlias: list):
        child = columnAlias
        for node in list(filter(lambda el: TreeNode in el.__class__.mro(), columnAlias)):
            self.construction.add_child(node)
        self.construction.columnAlias = child
    
    def with_aggregate(self, aggregate: str):
        child = aggregate
        self.construction.aggregate = child
    
    def with_direction(self, direction: Direction):
        child = direction
        self.construction.direction = child

    def build(self):
        return self.construction




from flowhigh.model.Op import Op
from flowhigh.model.CoordinateBlock import CoordinateBlock


class Filter(CoordinateBlock):
    op: Op = None

    def __init__(self):
        super().__init__()



from flowhigh.model.TreeNode import TreeNode

class FilterBuilder (object):
    construction: Filter

    
    def __init__(self) -> None:
        super().__init__()
        self.construction = Filter()
    
    def with_op(self, op: Op):
        child = op
        if TreeNode in Op.mro():
            self.construction.add_child(child)
        self.construction.op = child
    
    def with_pos(self, pos: str):
        child = pos
        self.construction.pos = child

    def build(self):
        return self.construction




from flowhigh.model.Ds import Ds
from flowhigh.model.Direction import Direction
from flowhigh.model.BaseExpr import BaseExpr
from flowhigh.model.ReferencableExpr import ReferencableExpr


class Create(BaseExpr, ReferencableExpr):
    refsch: str = None
    refdb: str = None
    scope: str = None
    refds: str = None
    query: Ds = None
    columnDef: list = []
    type_: str = None
    clusterBy: list = []
    ds: list = []

    def __init__(self):
        super().__init__()



from flowhigh.model.TreeNode import TreeNode

class CreateBuilder (object):
    construction: Create

    
    def __init__(self) -> None:
        super().__init__()
        self.construction = Create()
    
    def with_refsch(self, refsch: str):
        child = refsch
        self.construction.refsch = child
    
    def with_refdb(self, refdb: str):
        child = refdb
        self.construction.refdb = child
    
    def with_pos(self, pos: str):
        child = pos
        self.construction.pos = child
    
    def with_scope(self, scope: str):
        child = scope
        self.construction.scope = child
    
    def with_refds(self, refds: str):
        child = refds
        self.construction.refds = child
    
    def with_query(self, query: Ds):
        child = query
        if TreeNode in Ds.mro():
            self.construction.add_child(child)
        self.construction.query = child
    
    def with_alias(self, alias: str):
        child = alias
        self.construction.alias = child
    
    def with_columnDef(self, columnDef: list):
        child = columnDef
        for node in list(filter(lambda el: TreeNode in el.__class__.mro(), columnDef)):
            self.construction.add_child(node)
        self.construction.columnDef = child
    
    def with_type(self, type_: str):
        child = type_
        self.construction.type_ = child
    
    def with_direction(self, direction: Direction):
        child = direction
        self.construction.direction = child
    
    def with_clusterBy(self, clusterBy: list):
        child = clusterBy
        for node in list(filter(lambda el: TreeNode in el.__class__.mro(), clusterBy)):
            self.construction.add_child(node)
        self.construction.clusterBy = child
    
    def with_ds(self, ds: list):
        child = ds
        for node in list(filter(lambda el: TreeNode in el.__class__.mro(), ds)):
            self.construction.add_child(node)
        self.construction.ds = child

    def build(self):
        return self.construction




from flowhigh.model.CoordinateBlock import CoordinateBlock


class CreateStage(CoordinateBlock):
    with_: bool = None
    stageName: str = None
    comments: str = None
    directoryParam: str = None
    location: str = None
    tag: list = []
    fileFormat: str = None
    copyOptions: str = None

    def __init__(self):
        super().__init__()



from flowhigh.model.TreeNode import TreeNode

class CreateStageBuilder (object):
    construction: CreateStage

    
    def __init__(self) -> None:
        super().__init__()
        self.construction = CreateStage()
    
    def with_with(self, with_: bool):
        child = with_
        self.construction.with_ = child
    
    def with_comments(self, comments: str):
        child = comments
        self.construction.comments = child
    
    def with_stageName(self, stageName: str):
        child = stageName
        self.construction.stageName = child
    
    def with_pos(self, pos: str):
        child = pos
        self.construction.pos = child
    
    def with_directoryParam(self, directoryParam: str):
        child = directoryParam
        self.construction.directoryParam = child
    
    def with_location(self, location: str):
        child = location
        self.construction.location = child
    
    def with_tag(self, tag: list):
        child = tag
        for node in list(filter(lambda el: TreeNode in el.__class__.mro(), tag)):
            self.construction.add_child(node)
        self.construction.tag = child
    
    def with_copyOptions(self, copyOptions: str):
        child = copyOptions
        self.construction.copyOptions = child
    
    def with_fileFormat(self, fileFormat: str):
        child = fileFormat
        self.construction.fileFormat = child

    def build(self):
        return self.construction




from flowhigh.model.Filter import Filter
from flowhigh.model.CoordinateBlock import CoordinateBlock
from flowhigh.model.Searchable import Searchable


class Agg(CoordinateBlock, Searchable):
    filter_: Filter = None
    exprs: list = []

    def __init__(self):
        super().__init__()



from flowhigh.model.TreeNode import TreeNode

class AggBuilder (object):
    construction: Agg

    
    def __init__(self) -> None:
        super().__init__()
        self.construction = Agg()
    
    def with_filter(self, filter_: Filter):
        child = filter_
        if TreeNode in Filter.mro():
            self.construction.add_child(child)
        self.construction.filter_ = child
    
    def with_pos(self, pos: str):
        child = pos
        self.construction.pos = child
    
    def with_exprs(self, exprs: list):
        child = exprs
        for node in list(filter(lambda el: TreeNode in el.__class__.mro(), exprs)):
            self.construction.add_child(node)
        self.construction.exprs = child

    def build(self):
        return self.construction




from flowhigh.model.Expr import Expr


class WrappedExpr(object):
    expr: Expr = None

    def __init__(self):
        super().__init__()



from flowhigh.model.TreeNode import TreeNode

class WrappedExprBuilder (object):
    construction: WrappedExpr

    
    def __init__(self) -> None:
        super().__init__()
        self.construction = WrappedExpr()
    
    def with_expr(self, expr: Expr):
        child = expr
        if TreeNode in Expr.mro():
            self.construction.add_child(child)
        self.construction.expr = child

    def build(self):
        return self.construction




from flowhigh.model.Direction import Direction
from flowhigh.model.BaseExprCollectionHolder import BaseExprCollectionHolder
from flowhigh.model.Expr import Expr


class ExprExprCollectionHolder(BaseExprCollectionHolder, Expr):
    pos: str = None
    alias: str = None
    exprs: list = []
    direction: Direction = None

    def __init__(self):
        super().__init__()







from flowhigh.model.FuncType import FuncType
from flowhigh.model.Quantifier import Quantifier
from flowhigh.model.Sort import Sort
from flowhigh.model.Direction import Direction
from flowhigh.model.BaseExpr import BaseExpr
from flowhigh.model.Named import Named
from flowhigh.model.TypeCast import TypeCast


class Func(BaseExpr, Named, TypeCast):
    name: str = None
    withinGroup: Sort = None
    exprs: list = []
    type_: FuncType = None
    quantifier: Quantifier = None

    def __init__(self):
        super().__init__()



from flowhigh.model.TreeNode import TreeNode

class FuncBuilder (object):
    construction: Func

    
    def __init__(self) -> None:
        super().__init__()
        self.construction = Func()
    
    def with_pos(self, pos: str):
        child = pos
        self.construction.pos = child
    
    def with_withinGroup(self, withinGroup: Sort):
        child = withinGroup
        if TreeNode in Sort.mro():
            self.construction.add_child(child)
        self.construction.withinGroup = child
    
    def with_name(self, name: str):
        child = name
        self.construction.name = child
    
    def with_exprs(self, exprs: list):
        child = exprs
        for node in list(filter(lambda el: TreeNode in el.__class__.mro(), exprs)):
            self.construction.add_child(node)
        self.construction.exprs = child
    
    def with_alias(self, alias: str):
        child = alias
        self.construction.alias = child
    
    def with_quantifier(self, quantifier: Quantifier):
        child = quantifier
        self.construction.quantifier = child
    
    def with_type(self, type_: FuncType):
        child = type_
        self.construction.type_ = child
    
    def with_direction(self, direction: Direction):
        child = direction
        self.construction.direction = child

    def build(self):
        return self.construction




from flowhigh.model.Direction import Direction
from flowhigh.model.BaseExprHolder import BaseExprHolder
from flowhigh.model.Expr import Expr


class ExprExprHolder(BaseExprHolder, Expr):
    alias: str = None
    expr: Expr = None
    direction: Direction = None

    def __init__(self):
        super().__init__()







from flowhigh.model.JoinType import JoinType
from flowhigh.model.JoinSubType import JoinSubType
from flowhigh.model.DefinedAsType import DefinedAsType
from flowhigh.model.Ds import Ds
from flowhigh.model.Expr import Expr
from flowhigh.model.Direction import Direction
from flowhigh.model.BaseExpr import BaseExpr


class Join(BaseExpr):
    op: Expr = None
    definedAs: DefinedAsType = None
    subType: JoinSubType = None
    type_: JoinType = None
    ds: Ds = None

    def __init__(self):
        super().__init__()



from flowhigh.model.TreeNode import TreeNode

class JoinBuilder (object):
    construction: Join

    
    def __init__(self) -> None:
        super().__init__()
        self.construction = Join()
    
    def with_op(self, op: Expr):
        child = op
        if TreeNode in Expr.mro():
            self.construction.add_child(child)
        self.construction.op = child
    
    def with_definedAs(self, definedAs: DefinedAsType):
        child = definedAs
        self.construction.definedAs = child
    
    def with_pos(self, pos: str):
        child = pos
        self.construction.pos = child
    
    def with_alias(self, alias: str):
        child = alias
        self.construction.alias = child
    
    def with_subType(self, subType: JoinSubType):
        child = subType
        self.construction.subType = child
    
    def with_type(self, type_: JoinType):
        child = type_
        self.construction.type_ = child
    
    def with_ds(self, ds: Ds):
        child = ds
        if TreeNode in Ds.mro():
            self.construction.add_child(child)
        self.construction.ds = child
    
    def with_direction(self, direction: Direction):
        child = direction
        self.construction.direction = child

    def build(self):
        return self.construction




from flowhigh.model.Direction import Direction
from flowhigh.model.CoordinateBlock import CoordinateBlock
from flowhigh.model.Expr import Expr


class BaseExpr(CoordinateBlock, Expr):
    pos: str = None
    alias: str = None
    direction: Direction = None

    def __init__(self):
        super().__init__()









class DBOHier(object):
    dbo: list = []

    def __init__(self):
        super().__init__()



from flowhigh.model.TreeNode import TreeNode

class DBOHierBuilder (object):
    construction: DBOHier

    
    def __init__(self) -> None:
        super().__init__()
        self.construction = DBOHier()
    
    def with_dbo(self, dbo: list):
        child = dbo
        for node in list(filter(lambda el: TreeNode in el.__class__.mro(), dbo)):
            self.construction.add_child(node)
        self.construction.dbo = child

    def build(self):
        return self.construction




from flowhigh.model.Delete import Delete, DeleteBuilder
from flowhigh.model.InlineTable import InlineTable, InlineTableBuilder
from flowhigh.model.Op import Op, OpBuilder
from flowhigh.model.Ordered import Ordered
from flowhigh.model.Page import Page, PageBuilder
from flowhigh.model.Insert import Insert, InsertBuilder
from flowhigh.model.Update import Update, UpdateBuilder
from flowhigh.model.DeleteStatement import DeleteStatement, DeleteStatementBuilder
from flowhigh.model.Attr import Attr, AttrBuilder
from flowhigh.model.CreateView import CreateView, CreateViewBuilder
from flowhigh.model.InsertStatement import InsertStatement, InsertStatementBuilder
from flowhigh.model.DBO import DBO, DBOBuilder
from flowhigh.model.TreeNode import TreeNode
from flowhigh.model.CreateStage import CreateStage, CreateStageBuilder
from flowhigh.model.Sort import Sort, SortBuilder
from flowhigh.model.Then import Then, ThenBuilder
from flowhigh.model.MergeStatement import MergeStatement, MergeStatementBuilder
from flowhigh.model.MultiValue import MultiValue, MultiValueBuilder
from flowhigh.model.AntiPattern import AntiPattern, AntiPatternBuilder
from flowhigh.model.ExprExprHolder import ExprExprHolder
from flowhigh.model.BaseExprHolder import BaseExprHolder
from flowhigh.model.UpdateStatement import UpdateStatement, UpdateStatementBuilder
from flowhigh.model.QueryingStage import QueryingStage, QueryingStageBuilder
from flowhigh.model.Position import Position, PositionBuilder
from flowhigh.model.Const import Const, ConstBuilder
from flowhigh.model.CreateTableStatement import CreateTableStatement, CreateTableStatementBuilder
from flowhigh.model.ExprCollectionHolder import ExprCollectionHolder
from flowhigh.model.SubString import SubString
from flowhigh.model.ColumnDef import ColumnDef, ColumnDefBuilder
from flowhigh.model.Vfilter import Vfilter, VfilterBuilder
from flowhigh.model.Ds import Ds, DsBuilder
from flowhigh.model.Out import Out, OutBuilder
from flowhigh.model.BaseExpr import BaseExpr
from flowhigh.model.Expr import Expr
from flowhigh.model.ExprHolder import ExprHolder
from flowhigh.model.Copy import Copy, CopyBuilder
from flowhigh.model.ExprExprCollectionHolder import ExprExprCollectionHolder
from flowhigh.model.TypeCast import TypeCast
from flowhigh.model.Current import Current, CurrentBuilder
from flowhigh.model.Cast import Cast, CastBuilder
from flowhigh.model.Frame import Frame, FrameBuilder
from flowhigh.model.Vagg import Vagg, VaggBuilder
from flowhigh.model.Rotate import Rotate, RotateBuilder
from flowhigh.model.WrappedExprs import WrappedExprs, WrappedExprsBuilder
from flowhigh.model.BaseExprCollectionHolder import BaseExprCollectionHolder
from flowhigh.model.Func import Func, FuncBuilder
from flowhigh.model.In import In, InBuilder
from flowhigh.model.Case import Case, CaseBuilder
from flowhigh.model.ReferencableExpr import ReferencableExpr
from flowhigh.model.StructRef import StructRef, StructRefBuilder
from flowhigh.model.AntiPatterns import AntiPatterns, AntiPatternsBuilder
from flowhigh.model.Create import Create, CreateBuilder
from flowhigh.model.DBOHier import DBOHier, DBOHierBuilder
from flowhigh.model.MatchRecognize import MatchRecognize, MatchRecognizeBuilder
from flowhigh.model.Searchable import Searchable
from flowhigh.model.Asterisk import Asterisk, AsteriskBuilder
from flowhigh.model.Agg import Agg, AggBuilder
from flowhigh.model.Named import Named
from flowhigh.model.Wfunc import Wfunc, WfuncBuilder
from flowhigh.model.Statement import Statement, StatementBuilder
from flowhigh.model.CoordinateBlock import CoordinateBlock
from flowhigh.model.ParSeQL import ParSeQL, ParSeQLBuilder
from flowhigh.model.Error import Error, ErrorBuilder
from flowhigh.model.Join import Join, JoinBuilder
from flowhigh.model.TableSample import TableSample, TableSampleBuilder
from flowhigh.model.WrappedExpr import WrappedExpr, WrappedExprBuilder
from flowhigh.model.When import When, WhenBuilder
from flowhigh.model.Merge import Merge, MergeBuilder
from flowhigh.model.Filter import Filter, FilterBuilder
from flowhigh.model.TableFunc import TableFunc, TableFuncBuilder
from flowhigh.model.Else import Else, ElseBuilder
from flowhigh.model.Edge import Edge, EdgeBuilder